@@ -6,8 +6,8 @@ r"""
  | |  | | | |_) | |/ ____ \| |    _| |_  
  |_|  |_|_|_.__/|_/_/    \_\_|   |_____| 
 
-An alternative implement of Imjad API
-Project: https://github.com/mixmoe/HibiAPI
+A program that implements easy-to-use APIs for a variety of commonly used sites
+Repository: https://github.com/mixmoe/HibiAPI
 """  # noqa:W291,W293
 
 from importlib.metadata import version
